==> iTop-3.2.0-2-14758.zip: web/dictionaries/ui/pages/preferences/es_cr.dictionary.itop.preferences.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('ES CR', 'Spanish', 'Español, Castellano', [
	'UI:Favorites:General:ShowSummaryCards' => 'Show summary cards~~',
	'UI:Favorites:General:ShowSummaryCards+' => 'When hovering an hyperlink targeting an object, display a short summary of the object, if available for that class~~',
	'UI:Preferences:ActivityPanel:EntryFormOpened' => 'Formulario de entrada abierto de forma predeterminada',
	'UI:Preferences:ActivityPanel:EntryFormOpened+' => 'Si el formulario de entrada se abrirá cuando se muestre un objeto. Si no está marcado, aún podrá abrirlo haciendo click en el botón de redacción',
	'UI:Preferences:ActivityPanel:Title' => 'Panel de Actividad',
	'UI:Preferences:ChooseAPlaceholder' => 'Imagen de marcador de posición de usuario',
	'UI:Preferences:ChooseAPlaceholder+' => 'Elija una imagen de marcador de posición que se mostrará si el contacto vinculado a su usuario no tiene uno',
	'UI:Preferences:ChooseAPlaceholder:Success:Message' => 'Your placeholder image has been successfully updated~~',
	'UI:Preferences:General:Theme' => 'Tema',
	'UI:Preferences:General:Theme:DefaultThemeLabel' => '%1$s (predeterminado)',
	'UI:Preferences:General:Title' => 'General',
	'UI:Preferences:General:Toasts' => 'Toast notifications position~~',
	'UI:Preferences:General:Toasts:Bottom' => 'Bottom~~',
	'UI:Preferences:General:Toasts:Top' => 'Top~~',
	'UI:Preferences:Lists:Title' => 'Listas',
	'UI:Preferences:Notifications' => 'Notifications~~',
	'UI:Preferences:Notifications+' => 'Configure the notifications you want to receive <a href="%1$s">on this page</a>.~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset' => 'Restablecer',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset:Tooltip' => 'Volver al método abreviado de teclado predeterminado',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Tooltip' => 'Grabar un atajo de teclado',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Input:Hint' => 'Escriba un atajo de teclado',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Title' => 'Métodos abreviados de teclado de la aplicación',
	'UI:Preferences:RichText:Title' => 'Editor de texto enriquecido',
	'UI:Preferences:RichText:ToolbarState' => 'Estado predeterminado de la barra de herramientas',
	'UI:Preferences:RichText:ToolbarState:Collapsed' => 'Contraído',
	'UI:Preferences:RichText:ToolbarState:Expanded' => 'Expandido',
	'UI:Preferences:Tabs:Layout:Horizontal' => 'Horizontal',
	'UI:Preferences:Tabs:Layout:Label' => 'Formato',
	'UI:Preferences:Tabs:Layout:Vertical' => 'Vertical',
	'UI:Preferences:Tabs:Scrollable:Classic' => 'Clásico',
	'UI:Preferences:Tabs:Scrollable:Label' => 'Navigación',
	'UI:Preferences:Tabs:Scrollable:Scrollable' => 'Desplazable',
	'UI:Preferences:Tabs:Title' => 'Pestañas',
	'UI:Preferences:Title' => 'Preferencias',
	'UI:Preferences:UserInterface:Title' => 'Interfaz de Usuario',
]);

==> iTop-3.2.1-1-16749.zip: web/dictionaries/ui/pages/preferences/es_cr.dictionary.itop.preferences.php <==
<?php
/**
 * Spanish Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * @author Miguel Turrubiates <miguel_tf@yahoo.com>
 * @notas       Utilizar codificación UTF-8 para mostrar acentos y otros caracteres especiales 
 */
Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'UI:Preferences:Title' => 'Preferencias',
	'UI:Preferences:UserInterface:Title' => 'Interfaz de Usuario',
	'UI:Preferences:General:Title' => 'General',
	'UI:Preferences:General:Theme' => 'Tema',
	'UI:Preferences:General:Theme:DefaultThemeLabel' => '%1$s (predeterminado)',
	'UI:Favorites:General:ShowSummaryCards' => 'Mostrar tarjetas de resumen',
	'UI:Favorites:General:ShowSummaryCards+' => 'Al pasar el cursor sobre un hipervínculo dirigido a un objeto, muestra un breve resumen del objeto, si está disponible para esa clase',
	'UI:Preferences:Lists:Title' => 'Listas',
	'UI:Preferences:RichText:Title' => 'Editor de texto enriquecido',
	'UI:Preferences:RichText:ToolbarState' => 'Estado predeterminado de la barra de herramientas',
	'UI:Preferences:RichText:ToolbarState:Expanded' => 'Expandido',
	'UI:Preferences:RichText:ToolbarState:Collapsed' => 'Contraído',
	'UI:Preferences:ActivityPanel:Title' => 'Panel de Actividad',
	'UI:Preferences:ActivityPanel:EntryFormOpened' => 'Formulario de entrada abierto de forma predeterminada',
	'UI:Preferences:ActivityPanel:EntryFormOpened+' => 'Si el formulario de entrada se abrirá cuando se muestre un objeto. Si no está marcado, aún podrá abrirlo haciendo click en el botón de redacción',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Title' => 'Métodos abreviados de teclado de la aplicación',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Input:Hint' => 'Escriba un atajo de teclado',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Tooltip' => 'Grabar un atajo de teclado',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset' => 'Restablecer',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset:Tooltip' => 'Volver al método abreviado de teclado predeterminado',
	'UI:Preferences:Tabs:Title' => 'Pestañas',
	'UI:Preferences:Tabs:Layout:Label' => 'Formato',
	'UI:Preferences:Tabs:Layout:Horizontal' => 'Horizontal',
	'UI:Preferences:Tabs:Layout:Vertical' => 'Vertical',
	'UI:Preferences:Tabs:Scrollable:Label' => 'Navigación',
	'UI:Preferences:Tabs:Scrollable:Classic' => 'Clásico',
	'UI:Preferences:Tabs:Scrollable:Scrollable' => 'Desplazable',
	'UI:Preferences:General:Toasts' => 'Posición de notificaciones Toast',
	'UI:Preferences:General:Toasts:Bottom' => 'Final',
	'UI:Preferences:General:Toasts:Top' => 'Inicio',
	'UI:Preferences:ChooseAPlaceholder' => 'Imagen de marcador de posición de usuario',
	'UI:Preferences:ChooseAPlaceholder+' => 'Elija una imagen de marcador de posición que se mostrará si el contacto vinculado a su usuario no tiene uno',
	'UI:Preferences:ChooseAPlaceholder:Success:Message' => 'Imagen de marcador de posición se ha actualizado correctamente.',
	'UI:Preferences:Notifications' => 'Notificaciones',
	'UI:Preferences:Notifications+' => 'Configure las notificaciones que desea recibir <a href="%1$s">en esta página</a>.',
	
));
